@@ -1,8 +1,8 @@
 ;;; func-menu.el         --- Jump to a function within a buffer.
 ;;;
 ;;; David Hughes <d.hughes@videonetworks.com>
-;;; Last Modified: David Hughes 13th July 1998
-;;; Version: 2.57
+;;; Last Modified: David Hughes 10th August 1998
+;;; Version: 2.58
 ;;; Keywords: tools, c, lisp
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -240,7 +240,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;  Environment Initialisation  ;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defconst fume-version "2.57")
+(defconst fume-version "2.58")
 
 (defconst fume-developer "David Hughes <d.hughes@videonetworks.com>")
 
@@ -609,6 +609,7 @@ by func-menu, then do something along the lines of the following:
 
 ;;; Lisp
 ;;;
+;;; David Hughes <d.hughes@videonetworks.com>
 ;;; Vladimir Alexiev <vladimir@cs.ualberta.ca>
 (defvar fume-function-name-regexp-lisp
   (concat
@@ -616,7 +617,7 @@ by func-menu, then do something along the lines of the following:
                                         ;  for the construct |    (defun foo ()
    "(\\(def[^vc][a-z]*\\)"              ; Allow (def* except (defvar, (defconst
    "\\s-+"                              ; At least one whitespace
-   "'?[#:?/A-Za-z0-9_+>-]+"             ; Allow (defalias 'foo 'bar)
+   "'?[#:?%@!/A-Za-z0-9_+<>-]+"         ; Allow (defalias 'foo 'bar)
    "\\s-*"                              ; Whitespace
    "\\(nil\\|(\\)"                      ; nil or (arg list
    )
@@ -885,7 +886,10 @@ by func-menu, then do something along the lines of the following:
 (defvar fume-function-name-regexp-make
   "^\\(\\(\\$\\s(\\)?\\(\\w\\|\\.\\)+\\(:sh\\)?\\(\\s)\\)?\\)\\s *\\(::?\\|\\+?=\\)"
   "Expression to get makefile target names")
-(add-hook 'makefile-mode-hook 'fume-add-menubar-entry)
+;; The original version from D.Hughes has this uncommented, but XEmacs 20.4
+;; has it commented and it is way too slow on non-trivial Makefiles so I'm
+;; commenting it back out.  -slb Aug 6, 1998.
+;; (add-hook 'makefile-mode-hook 'fume-add-menubar-entry)
 
 ;;; Directory Listings
 ;;;
@@ -1735,7 +1739,8 @@ Otherwise returns fume-function-name-regexp"
     (set fume-modeline-buffer-identification
          (if (not (and fume-display-in-modeline-p fname))
              fume-modeline-buffer-identification-0
-           (setq fname (format "'%s'" (fume-trim-string fname)))
+           (setq fname (replace-in-string fname "%" "%%")
+                 fname (format "'%s'" (fume-trim-string fname)))
            (if (eq fume-display-in-modeline-p t)
                (list fume-modeline-buffer-identification-1 " " fname)
              fname))))
