@@ -335,12 +335,12 @@ static char * right[] = {
     ["Rescan buffer"	outline-rescan-buffer		t])
   "Menu of commands for outline glyphs.")
 
-(set-pixmap-contributes-to-line-height outline-down-arrow nil)
-(set-pixmap-contributes-to-line-height outline-up-arrow nil)
-(set-pixmap-contributes-to-line-height outline-down-arrow-mask nil)
-(set-pixmap-contributes-to-line-height outline-up-arrow-mask nil)
-(set-pixmap-contributes-to-line-height outline-right-arrow nil)
-(set-pixmap-contributes-to-line-height outline-right-arrow-mask nil)
+(set-glyph-contrib-p outline-down-arrow nil)
+(set-glyph-contrib-p outline-up-arrow nil)
+(set-glyph-contrib-p outline-down-arrow-mask nil)
+(set-glyph-contrib-p outline-up-arrow-mask nil)
+(set-glyph-contrib-p outline-right-arrow nil)
+(set-glyph-contrib-p outline-right-arrow-mask nil)
 
 (require 'annotations)
 (require 'advice)			; help me doctor !
